"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mediaurl import MediaURL, MediaURLTypedDict
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class AudioResponseTypedDict(TypedDict):
    r"""Response model for audio generation."""

    audio: MediaURLTypedDict
    r"""The generated audio."""


class AudioResponse(BaseModel):
    r"""Response model for audio generation."""

    audio: MediaURL
    r"""The generated audio."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class MediaURLTypedDict(TypedDict):
    r"""A URL from which media can be accessed."""

    url: str
    r"""The URL where the media can be accessed."""


class MediaURL(BaseModel):
    r"""A URL from which media can be accessed."""

    url: str
    r"""The URL where the media can be accessed."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TextToSpeechParamsTypedDict(TypedDict):
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for text to speech generation."""
    text: NotRequired[str]
    r"""Text input for speech generation."""
    description: NotRequired[str]
    r"""Description of speaker to steer text to speech generation."""


class TextToSpeechParams(BaseModel):
    model_id: Optional[str] = ""
    r"""Hugging Face model ID used for text to speech generation."""

    text: Optional[str] = ""
    r"""Text input for speech generation."""

    description: Optional[str] = (
        "A male speaker delivers a slightly expressive and animated speech with a moderate speed and pitch."
    )
    r"""Description of speaker to steer text to speech generation."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ParamsTypedDict(TypedDict):
    r"""Initial parameters for the model."""


class Params(BaseModel):
    r"""Initial parameters for the model."""


class LiveVideoToVideoParamsTypedDict(TypedDict):
    subscribe_url: str
    r"""Source URL of the incoming stream to subscribe to."""
    publish_url: str
    r"""Destination URL of the outgoing stream to publish."""
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for image generation."""
    params: NotRequired[ParamsTypedDict]
    r"""Initial parameters for the model."""


class LiveVideoToVideoParams(BaseModel):
    subscribe_url: str
    r"""Source URL of the incoming stream to subscribe to."""

    publish_url: str
    r"""Destination URL of the outgoing stream to publish."""

    model_id: Optional[str] = ""
    r"""Hugging Face model ID used for image generation."""

    params: Optional[Params] = None
    r"""Initial parameters for the model."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class LiveVideoToVideoResponseTypedDict(TypedDict):
    r"""Response model for live video-to-video generation."""

    subscribe_url: str
    r"""Source URL of the incoming stream to subscribe to"""
    publish_url: str
    r"""Destination URL of the outgoing stream to publish to"""


class LiveVideoToVideoResponse(BaseModel):
    r"""Response model for live video-to-video generation."""

    subscribe_url: str
    r"""Source URL of the incoming stream to subscribe to"""

    publish_url: str
    r"""Destination URL of the outgoing stream to publish to"""
